==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Spinner/Spinner.base.js <==
import '../node_modules/core-js/modules/es.array.index-of.js';
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { DelayedRender } from '../DelayedRender.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var Spinner = function (_StatelessComponent) {
  _inherits(Spinner, _StatelessComponent);

  var _super = _createSuper(Spinner);

  function Spinner() {
    _classCallCheck(this, Spinner);

    return _super.apply(this, arguments);
  }

  _createClass(Spinner, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          styles = _context$props.styles,
          className = _context$props.className,
          ariaLabel = _context$props.ariaLabel,
          ariaLive = _context$props.ariaLive,
          size = _context$props.size,
          label = _context$props.label,
          labelPosition = _context$props.labelPosition;
      var statusMessage = ariaLabel;
      var classNames = getClassNames(styles, {
        theme: theme,
        size: size,
        className: className,
        labelPosition: labelPosition
      });
      return h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.circle
      }), (context.scopedSlots["default"] || label) && h("div", {
        "class": classNames.label
      }, [context.scopedSlots["default"] ? context.scopedSlots["default"]({}) : label]), statusMessage && h("div", {
        "attrs": {
          "role": "status",
          "aria-live": ariaLive
        }
      }, [h(DelayedRender, [h("div", {
        "class": classNames.screenReaderText
      }, [statusMessage])])])]);
    }
  }]);

  return Spinner;
}(StatelessComponent);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], Spinner.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], Spinner.prototype, "ariaLabel", void 0);

__decorate([Prop({
  type: String,
  "default": 'polite',
  validator: function validator(v) {
    return ['assertive', 'polite', 'off'].indexOf(v) > -1;
  }
}), __metadata("design:type", String)], Spinner.prototype, "ariaLive", void 0);

__decorate([Prop({
  type: String,
  "default": 'bottom'
}), __metadata("design:type", String)], Spinner.prototype, "labelPosition", void 0);

__decorate([Prop({
  type: Number,
  "default": 20
}), __metadata("design:type", Number)], Spinner.prototype, "size", void 0);

Spinner = __decorate([Component], Spinner);
var SpinnerBase = Spinner;

export default SpinnerBase;

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Spinner/Spinner.base.js <==
import 'core-js/modules/es.array.index-of';
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import 'core-js/modules/es.number.constructor';
import { DelayedRender } from '../DelayedRender.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var Spinner = function (_StatelessComponent) {
  _inherits(Spinner, _StatelessComponent);

  var _super = _createSuper(Spinner);

  function Spinner() {
    _classCallCheck(this, Spinner);

    return _super.apply(this, arguments);
  }

  _createClass(Spinner, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          styles = _context$props.styles,
          className = _context$props.className,
          ariaLabel = _context$props.ariaLabel,
          ariaLive = _context$props.ariaLive,
          size = _context$props.size,
          label = _context$props.label,
          labelPosition = _context$props.labelPosition;
      var statusMessage = ariaLabel;
      var classNames = getClassNames(styles, {
        theme: theme,
        size: size,
        className: className,
        labelPosition: labelPosition
      });
      return h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.circle
      }), (context.scopedSlots.default || label) && h("div", {
        "class": classNames.label
      }, [context.scopedSlots.default ? context.scopedSlots.default({}) : label]), statusMessage && h("div", {
        "attrs": {
          "role": "status",
          "aria-live": ariaLive
        }
      }, [h(DelayedRender, [h("div", {
        "class": classNames.screenReaderText
      }, [statusMessage])])])]);
    }
  }]);

  return Spinner;
}(StatelessComponent);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], Spinner.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], Spinner.prototype, "ariaLabel", void 0);

__decorate([Prop({
  type: String,
  default: 'polite',
  validator: function validator(v) {
    return ['assertive', 'polite', 'off'].indexOf(v) > -1;
  }
}), __metadata("design:type", String)], Spinner.prototype, "ariaLive", void 0);

__decorate([Prop({
  type: String,
  default: 'bottom'
}), __metadata("design:type", String)], Spinner.prototype, "labelPosition", void 0);

__decorate([Prop({
  type: Number,
  default: 20
}), __metadata("design:type", Number)], Spinner.prototype, "size", void 0);

Spinner = __decorate([Component], Spinner);
var SpinnerBase = Spinner;

export default SpinnerBase;
